@@ -3,7 +3,7 @@ import os
 
 import numpy as np
 import pandas as pd
-import pandas.util.testing as tm
+import pandas.testing as tm
 import pytest
 
 import pandas_datareader.data as web
