@@ -198,7 +198,11 @@ class YahooDailyReader(_DailyBaseReader):
 
                 def split_ratio(row):
                     if float(row["Numerator"]) > 0:
-                        return eval(row["Splitratio"])
+                        if ":" in row["Splitratio"]:
+                            n, m = row["Splitratio"].split(":")
+                            return float(m) / float(n)
+                        else:
+                            return eval(row["Splitratio"])
                     else:
                         return 1
 
